@@ -36,6 +36,8 @@ def cmd(add_cmd, is_args=False):
             pattern = "^/" + add_cmd
         elif is_args=="notes1":
             pattern = "^/" + add_cmd + "(\S+)"
+        elif is_args=="unpin":
+            pattern = "^/" + add_cmd + "($| (.*))"
         else:
             pattern = "^/" + add_cmd + "$"
         utilsbot.add_event_handler(
